@@ -11,11 +11,7 @@ import re
 
 from ._utils import typecast
 
-try:
-    from ._utils import file  # NOQA
-except ImportError:
-    pass
-
+file = open  # NOQA
 __version__ = '0.6.2-casper.4'
 
 
@@ -185,8 +181,7 @@ class Argument(ChildPattern):
 
     @property
     def name_stripped(self):
-        return self.name[1:-1] \
-            if self.name[0] == '<' and self.name[-1] == '>' else self.name
+        return self.name[1:-1] if self.name[0] == '<' and self.name[-1] == '>' else self.name
 
 
 class Command(Argument):
